==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-session/lxqt-session/lxqt-session_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <source>LXQt Session Crash Report</source>
        <translation>Zpráva o pádu sezení LXQtu</translation>
    </message>
    <message>
        <source>Application &apos;%1&apos; crashed too many times. Its autorestart has been disabled for current session.</source>
        <translation>Program &apos;%1&apos; spadl příliš mnohokrát. Jeho automatické spuštění bylo pro nynější sezení zakázáno.</translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="302"/>
        <source>Crash Report</source>
        <translation>Zpráva o pádu</translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="303"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; spadl příliš mockrát. Automatické znovuspuštění bylo zakázáno až do příštího přihlášení.</translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Vítejte v LXQt-Qt</translation>
    </message>
    <message>
        <source>&lt;b&gt;Welcome to LXQt&lt;/b&gt;
&lt;p&gt;
Before starting to use the LXQt, you might want to select the Windows Manager:</source>
        <translation>&lt;b&gt;Vítejte v LXQt-Qt&lt;/b&gt;
&lt;p&gt;
Před započetím s prací byste mohl chtít vybrat si správce oken:</translation>
    </message>
    <message>
        <source>You can change the Window Manager later at any time via LXQt Session Configurator.</source>
        <translation>Správce oken můžete později změnit v nastavení sezení pro LXQt.</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="62"/>
        <source>Other ...</source>
        <translation>Jiné...</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="63"/>
        <source>Choose your favorite one.</source>
        <translation>Vyberte oblíbené.</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vítejte v LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Vyberte, prosím, výchozího správce oken.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation>Toto budete moci kdykoli změnit přes Nastavení → Nastavení sezení → Základní nastavení.</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-session/lxqt-session/lxqt-session_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <source>LXQt Session Crash Report</source>
        <translation type="vanished">Zpráva o pádu sezení LXQtu</translation>
    </message>
    <message>
        <source>Application &apos;%1&apos; crashed too many times. Its autorestart has been disabled for current session.</source>
        <translation type="vanished">Program &apos;%1&apos; spadl příliš mnohokrát. Jeho automatické spuštění bylo pro nynější sezení zakázáno.</translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="309"/>
        <source>Crash Report</source>
        <translation>Zpráva o pádu</translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="310"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; spadl příliš mockrát. Automatické znovuspuštění bylo zakázáno až do příštího přihlášení.</translation>
    </message>
</context>
<context>
    <name>SessionApplication</name>
    <message>
        <location filename="../../../src/main.cpp" line="58"/>
        <source>Configuration file path.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/main.cpp" line="58"/>
        <location filename="../../../src/main.cpp" line="59"/>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/main.cpp" line="59"/>
        <source>Window manager to use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Vítejte v LXQt-Qt</translation>
    </message>
    <message>
        <source>&lt;b&gt;Welcome to LXQt&lt;/b&gt;
&lt;p&gt;
Before starting to use the LXQt, you might want to select the Windows Manager:</source>
        <translation type="vanished">&lt;b&gt;Vítejte v LXQt-Qt&lt;/b&gt;
&lt;p&gt;
Před započetím s prací byste mohl chtít vybrat si správce oken:</translation>
    </message>
    <message>
        <source>You can change the Window Manager later at any time via LXQt Session Configurator.</source>
        <translation type="vanished">Správce oken můžete později změnit v nastavení sezení pro LXQt.</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="62"/>
        <source>Other ...</source>
        <translation>Jiné...</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="63"/>
        <source>Choose your favorite one.</source>
        <translation>Vyberte oblíbené.</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vítejte v LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Vyberte, prosím, výchozího správce oken.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation>Toto budete moci kdykoli změnit přes Nastavení → Nastavení sezení → Základní nastavení.</translation>
    </message>
</context>
</TS>
